Fastscapelib
============

|Build Status| |Doc Status| |Zenodo|

A C++/Python library of efficient and reusable algorithms for landscape
evolution modeling. It aims at providing a (bare bones) toolkit for building
your own Landscape Evolution Models (LEMs) or integrating it with other existing
codes or models.

.. |Build Status| image:: https://github.com/fastscape-lem/fastscapelib/actions/workflows/tests.yml/badge.svg?branch=main
   :target: https://github.com/fastscape-lem/fastscapelib/actions/workflows/tests.yml
   :alt: Build Status
.. |Doc Status| image:: http://readthedocs.org/projects/fastscapelib/badge/?version=latest
   :target: http://fastscapelib.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status
.. |Zenodo| image:: https://zenodo.org/badge/133639708.svg
   :target: https://zenodo.org/badge/latestdoi/133639708
   :alt: Citation

Documentation
-------------

Documentation is hosted on ReadTheDocs:
http://fastscapelib.readthedocs.io

License
-------

This library is licensed under the `GNU General Public License
v3.0`_. See LICENSE file.

.. _`GNU General Public License v3.0`: https://www.gnu.org/licenses/gpl-3.0.en.html

Fastscapelib uses some code from other projects. Their licenses are
reproduced in the "licenses" directory.

Acknowledgment
--------------

This project is supported by the `Earth Surface Process Modelling`_
group of the GFZ Helmholtz Centre Potsdam.

.. _`Earth Surface Process Modelling`: http://www.gfz-potsdam.de/en/section/earth-surface-process-modelling/


Citing fastscapelib
-------------------

If you use Fastscapelib in a scientific publication, we would
appreciate a `citation`_.

.. _`citation`: http://fastscapelib.readthedocs.io/en/latest/citation.html
